@@ -23,7 +23,7 @@ import websockets
 from websockets.exceptions import ConnectionClosedOK
 
 
-__version__ = '1.3.1'
+__version__ = '1.4.0'
 
 logger = logging.getLogger('websockets')
 logger.setLevel(logging.DEBUG if '--debug' in sys.argv else logging.INFO)
@@ -342,7 +342,11 @@ def get_local_files_metadata():
 
 
 def get_env_metadata():
-    data = {'cwd': os.getcwd()}
+    data = {
+        'cwd': os.getcwd(),
+        'requirements': read('requirements.txt'),
+        'dockerfile': read('Dockerfile'),
+    }
     try:
         return dict(
             data,
@@ -362,6 +366,14 @@ def get_env_metadata():
         )
 
 
+def read(fname):
+    try:
+        with open(fname) as f:
+            return f.read()
+    except Exception:
+        pass
+
+
 def slicing_window(iterable, size=5):
     start = 0
     while iterable[start:start + size]:
@@ -378,7 +390,7 @@ async def main():
         if data['info']['version'] != __version__:
             print(
                 colorama.Back.RED +
-                colorama.Fore.BLACK +
+                colorama.Fore.WHITE +
                 "!! You are using an outdated iskra-cli, ugrade:" +
                 colorama.Style.RESET_ALL
             )
